pub enum Section {
Owned(usize, Vec<u8>),
Borrowed(usize, Range<usize>),
}Expand description
ELF section
Variants
Owned(usize, Vec<u8>)
Owned section data.
The first field is virtual address of the section. The second field is the actual section data.
Borrowed(usize, Range<usize>)
Borrowed section data.
The first field is virtual address of the section. The second field can be used to index the input ELF buffer to retrieve the section data.